## Creating Variables for Core Instance module. You can add default values for each variable mentioned below.

variable "instance_type" {
  description = "Select one of the instance types"
  type        = string
  validation {
    condition     = contains(["t2.medium", "t2.large", "t2.xlarge", "t3a.medium", "t3a.large", "t3a.xlarge", "t3.medium", "t3.large", "t3.xlarge", "m5a.large", "m5.large", "m5n.large", "m5a.xlarge", "m5.xlarge", "m5n.xlarge"], var.instance_type)
    error_message = "Argument 'instance_type' must one of t2.medium, t2.large, t2.xlarge, t3a.medium, t3a.large, t3a.xlarge, t3.medium, t3.large, t3.xlarge, m5a.large, m5.large, m5n.large, m5a.xlarge, m5.xlarge, or m5n.xlarge."
  }
}

variable "credit_specification" {
  description = "Credit Specification based on Instance Type"
  type        = map(any)
  default = {
    "t2.medium"  = "unlimited",
    "t2.large"   = "unlimited",
    "t2.xlarge"  = "unlimited",
    "t3a.medium" = "unlimited",
    "t3a.large"  = "unlimited",
    "t3a.xlarge" = "unlimited",
    "t3.medium"  = "unlimited",
    "t3.large"   = "unlimited",
    "t3.xlarge"  = "unlimited",
    "m5a.large"  = "standard",
    "m5.large"   = "standard",
    "m5n.large"  = "standard",
    "m5a.xlarge" = "standard",
    "m5.xlarge"  = "standard",
    "m5n.xlarge" = "standard"
  }
}

variable "instance_name" {
  description = "The name of the Instance"
  type        = string
}

variable "keyname" {
  description = "Key Pair Name"
}

variable "userdata" {
  description = "(Optional) Advanced Deployment: Paste here configUserData.json file content values"
  type        = string
}

variable "ec2regionmap" {
  description = "AMI mapping based on Region"
  type        = map(any)
  default = {
    af-south-1     = "ami-046b0b8122c32d7cf"
    ap-east-1      = "ami-0cc9794919809d4bc"
    ap-northeast-1 = "ami-0cf78e5a509642f00"
    ap-northeast-2 = "ami-031d383627545b4d5"
    ap-northeast-3 = "ami-064d23bee6b0a1bc4"
    ap-south-1     = "ami-071891c6633b89e02"
    ap-southeast-1 = "ami-0c85c6f82672bff6b"
    ap-southeast-2 = "ami-07c8868df044227da"
    ca-central-1   = "ami-03acbbae9a3de50af"
    eu-central-1   = "ami-008d4ff84b5563410"
    eu-north-1     = "ami-0eef3c51c24e1fdc4"
    eu-south-1     = "ami-030152c3c007886c2"
    eu-west-1      = "ami-043960914a00af0d8"
    eu-west-2      = "ami-05f7e4de7f320d4e7"
    eu-west-3      = "ami-00e05bf679e5879df"
    me-south-1     = "ami-064e1c4b3894678da"
    sa-east-1      = "ami-0aaa95da4e13fe1ba"
    us-east-1      = "ami-047984319951ad3d1"
    us-east-2      = "ami-0d30b0772e6c0c8d1"
    us-gov-east-1  = "ami-03109bfdc5140d81d"
    us-gov-west-1  = "ami-0147110ac014b72e9"
    us-west-1      = "ami-0519c2ec64b8a83a2"
    us-west-2      = "ami-054163d8785836977"
  }
}

variable "deployment_region" {
  description = "Region to deploy the infrastructure in"
}

variable "external_subnet_id" {
  description = "Select an External Subnet (WARNING !! must be on the same availability zone as Internal Subnet)"
}

variable "internal_subnet_id" {
  description = "Select an Internal Subnet (WARNING !! must be on the same availability zone as Internal Subnet)"
}

variable "stack_name" {
  description = "Stack name for deployment"
}

variable "vpc_id" {
  description = "VPC ID used for deployment"
}